#
# spec file for package crossplane-cli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

%define executable_name crossplane

Name:           crossplane-cli
Version:        1.20.0
Release:        1.1
Summary:        The Cloud Native Control Plane
License:        Apache-2.0
URL:            https://github.com/crossplane/crossplane
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.20
Provides:       crossplane = %{version}

%description
Crossplane is a framework for building cloud native control planes without
needing to write code. It has a highly extensible backend that enables you to
build a control plane that can orchestrate applications and infrastructure no
matter where they run, and a highly configurable frontend that puts you in
control of the schema of the declarative API it offers.

Crossplane is a Cloud Native Computing Foundation project.

%prep
%autosetup -p 1 -a 1

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X github.com/crossplane/crossplane/internal/version.version=%{version}" \
   -o bin/%{executable_name} ./cmd/crossplane

%install
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%changelog
* Thu May 22 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.20.0:
  Full changelog
  https://github.com/crossplane/crossplane/releases/tag/v1.20.0
  * CLI-related changes:
  - Crossplane CLI shell completions: Shell completions are now
    included for the crossplane CLI, enabling you to autocomplete
    crossplane commands with arguments and values. Try out
    crossplane beta trace and instead of typing or pasting the
    resource name, just let <tab> auto complete find it for you!
    Learn how to get started with shell completions in the CLI
    reference.
    https://docs.crossplane.io/v1.20/cli/#installing-shell-autocompletions
  * Dependencies
  - Use latest buf
  - Use the new buf-action
  - build: bump go to 1.23.9
  - chore(deps): bump crossplane-runtime to v1.20.0
  - chore(deps): bump crossplane-runtime to v1.20.0-rc.1
  - chore(deps): bump golang version in Earthfile to v1.23.7
  - chore(deps): pin bufbuild/buf-action action to 5150a1e
  - chore(deps): run go mod tidy
  - chore(deps): update module github.com/go-jose/go-jose/v4 to
    v4.0.5 [security] (#6297)
  - chore(deps): update module github.com/golang-jwt/jwt/v4 to
    v4.5.2 [security]
  - chore(deps): update module github.com/open-policy-agent/opa
    to v1 [security]
  - chore(deps): update module golang.org/x/crypto to v0.35.0
    [security]
  - chore(deps): update module golang.org/x/oauth2 to v0.27.0
    [security]
  - chore: bumping crossplane-runtime dependency in main to
    1.20.0-rc.0
  - chore: bumping renovate baseBranches for 1.19
  - chore: run +go-generate
  - chore: update release table for 1.19
  - fix(cli): consider --insecure-skip-tls-verify flag for
    crossplane xpkg push command
  - fix(deps): update module github.com/golang-jwt/jwt/v5 to
    v5.2.2 [security]
  - fix(deps): update module golang.org/x/net to v0.36.0
    [security]
  - fix(deps): update module golang.org/x/net to v0.38.0
    [security]
* Wed Mar 26 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.19.1:
  * fix(deps): update module github.com/golang-jwt/jwt/v5 to v5.2.2
    [security]
  * chore(deps): update module github.com/golang-jwt/jwt/v4 to
    v4.5.2 [security]
  * fix(deps): update module golang.org/x/net to v0.36.0 [security]
  * chore(deps): update module golang.org/x/crypto to v0.35.0
    [security]
  * chore(deps): bump golang version in Earthfile to v1.23.7
  * chore(deps): update module golang.org/x/oauth2 to v0.27.0
    [security]
  * fix(crank): render private pull
  * chore(deps): update module github.com/go-jose/go-jose/v4 to
    v4.0.5 [security] (#6299)
* Wed Feb 12 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.19.0:
  https://github.com/crossplane/crossplane/releases/tag/v1.19.0
  CLI-related highlights:
  * The Crossplane CLI commands such as render and validate that
    download Crossplane packages now work well with private
    repositories.
  CLI-related changelog:
  * fix(crank): add function as input for extensions in cli for
    validate by @haarchri in #6087
  * feat(cli): include status conditions in output of render
    command by @jbw976 in #6121
  * feat(cli): Add ability to pull images from private registry by
    @cychiang in #6227
  * fix(cli): Resolve duplicate validate results due to multiple
    version of dependencies in cache by @cychiang in #6205
* Wed Feb 12 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.18.3:
  * [Backport release-1.18] Use an uncached client to retrieve
    composed resources not found in the cache (#6276)
  * fix(deps): update module github.com/go-git/go-git/v5 to v5.13.0
    [security]
  * fix(deps): update module golang.org/x/net to v0.33.0 [security]
* Wed Dec 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.18.2:
  no CLI-related changes in changelog
* Fri Nov 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.18.1:
  no CLI-related changes in changelog
* Tue Nov  5 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.18.0:
  Large update, please find the full changelog here:
  https://github.com/crossplane/crossplane/releases/tag/v1.18.0
  CLI-related changes:
  * Support for converting to function-environment-configs.
  * Support for passing credentials to functions in render function.
  * beta validate improvements.
* Fri Oct 25 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.17.2:
  * build: bump golang to 1.22.8
  * Add contexts to RuntimeFunctionRunner
  * Use a mix of v1 and v1beta functions in E2E tests
  * Support installing Functions with v1 package metadata
* Sat Sep 21 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package crossplane-cli: CLI for the crossplane infrastructure
  automation platform
